Class: Google::Api::GoSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/api/client.rb

Overview

Settings for Go client libraries.

Defined Under Namespace

Classes: RenamedServicesEntry

Instance Attribute Summary collapse

Instance Attribute Details

#common::Google::Api::CommonLanguageSettings

Returns Some settings.

Returns:



342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'proto_docs/google/api/client.rb', line 342

class GoSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class RenamedServicesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#renamed_services::Google::Protobuf::Map{::String => ::String}

Returns Map of service names to renamed services. Keys are the package relative service names and values are the name to be used for the service client and call options.

Example:

publishing:
  go_settings:
    renamed_services:
      Publisher: TopicAdmin.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Map of service names to renamed services. Keys are the package relative service names and values are the name to be used for the service client and call options.

    Example:

    publishing:
      go_settings:
        renamed_services:
          Publisher: TopicAdmin
    


342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'proto_docs/google/api/client.rb', line 342

class GoSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class RenamedServicesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end